pub fn triangular_part(
upper: bool,
with_diag: bool,
rs: &mut WorkStack,
ws: &mut WorkStack,
_xs: &mut WorkStack,
) -> Result<(), ExprEvalError>Expand description
Given a square matrix expression, compute a sparse expression containing the elements from one triangular part of the matrix.
Arguments
upperIndicates if we request the upper or the lower part of the matrix.with_diagIndicates if the diagonal elements should be included.